Installation
------------
The QuadMomPy package can be easily installed by
::

    pip install quadmompy

or from the project repository
::

    pip install -e .

A comprehensive documentation and additional examples are only available in the project repository on GitLab/GitHub. Use 

::

    git clone https://gitlab.com/puetzm/quadmompy.git

to clone the code from the GitLab repository or

::

    git clone https://github.com/puetzmi/quadmompy.git

to clone from the project mirror on GitHub.

The repository also includes a `Dockerfile` to run tests and use the QuadMomPy package in a docker image.
